const sdk = require('axway-flow-sdk');
const action = require('./action');

function getFlowNodes() {
	const flownodes = sdk.init(module);

	// The unique name of your flow-node.  You can define multiple flow-nodes in this
	// file, but one is typical.
	flownodes
		.add('javascript', {
			name: 'JavaScript',
			icon: 'icon.svg',
			description: 'Execute javascript code.',
			category: 'core'
		}).method('Execute', {
			description: 'Executes JavaScript code.'
		}, true)
		.parameter('data', {
			description: 'The value to apply as the `data` argument to the javascript code.  For objects and arrays, `data` is passed by reference.'
		}, false)
		.parameter('code', {
			description: 'A javascript function body. Supports `await` and returning promises',
			type: 'string',
			format: 'multiline'
		}, true)
		.group('Advanced')
		.parameter('unsafe', {
			title: 'Unsafe Mode',
			description: 'USE WITH CAUTION. When enabled, JavaScript is not executed in a sandboxed environment and all globals are available.',
			default: false,
			type: 'boolean'
		}, false)
		.output('next', {
			name: 'Next',
			description: 'The value that the function returned or was resolved with.',
			context: '$.result',
			schema: {}
		})
		.output('error', {
			name: 'Error',
			context: '$.error',
			schema: {}
		})
		.action(action);

	return Promise.resolve(flownodes);
}

module.exports = getFlowNodes;
